import { SvelteComponentTyped } from "svelte";
declare const __propDef: {
    props: Record<string, never>;
    events: {
        [evt: string]: CustomEvent<any>;
    };
    slots: {
        default: {
            hovering: boolean;
        };
    };
};
export type HoverDrawSvgProps = typeof __propDef.props;
export type HoverDrawSvgEvents = typeof __propDef.events;
export type HoverDrawSvgSlots = typeof __propDef.slots;
/**
 * A lightweight Svelte component to draw SVG on hover.
 * - Prerequisite: SVG shape must have `stroke`
 *   ```html
 * 	<svg stroke="#000" stroke-width="2">
 * 	  <path />
 * 	</svg>
 * 	```
 * - Expose the `hovering` state to the component. (optional)
 *  - Use `--duration=[number]` to set the draw time. (default 1s)
 *  - Inline SVG:
 * 	```svelte
 * 	 <HoverDrawSVG>
 * 	   <svg>
 * 	     <path />
 * 	   </svg>
 * 	 </HoverDrawSVG>
 * 	```
 *  - SVG Component (draw in 2 seconds):
 * 	```svelte
 * 	 <HoverDrawSVG --duration="2">
 * 	   <SvgComponent />
 * 	 </HoverDrawSVG>
 * 	```
 * - Nested elements (expose `hovering` status):
 * 	```svelte
 * 	 <HoverDrawSVG let:hovering>
 * 	   <a href="/" class:hoverEffect={hovering}>
 * 	     <svg>
 * 	       <path />
 * 	     </svg>
 * 	   </a>
 * 	 </HoverDrawSVG>
 * 	```
 */
export default class HoverDrawSvg extends SvelteComponentTyped<HoverDrawSvgProps, HoverDrawSvgEvents, HoverDrawSvgSlots> {
}
export {};
